Unifont Utils
=============

This project provides a set of tools for working with the Unifont font.

See the documentation at `Read the Docs <https://unifont-utils.readthedocs.io/>`_
for more information.

Installation
------------

Install the package from PyPI using the following command:

.. code-block:: shell

    pip install unifont_utils

Feedback
--------

This project is still in its early stages of development. See the
`GitHub repository <https://github.com/SkyEye-FAST/unifont_utils>`_ for more
information.

Please feel free to raise issues for any problems encountered or
feature suggestions.

Pull requests are welcome.
